"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const os_1 = __importDefault(require("os"));
const path_1 = __importDefault(require("path"));
const handlebars_1 = __importDefault(require("handlebars"));
const getRawPath = (filePath) => os_1.default.platform() === 'win32' ? filePath.replace(/\\/g, '\\\\') : filePath;
function generateBasicConfig(options) {
    const { projectRoot, imageBaseURL, cfgOutputDir, useHyCSS = true, mode, filterModulesPath } = options;
    const cfgName = 'metro-config.js';
    const cfgPath = path_1.default.resolve(cfgOutputDir || projectRoot, cfgName);
    const generateBasicConfig = () => {
        const template = fs_1.default.readFileSync(path_1.default.resolve(__dirname, cfgName)).toString();
        const context = {
            PROJECT_ROOT: getRawPath(projectRoot),
            IMAGE_BASE_URL: imageBaseURL,
            FILTER_MODULES_PATH: getRawPath(filterModulesPath || ''),
            MODE: mode,
            USE_HY_CSS: useHyCSS,
            CSS_TRANSFORMER_PATH: getRawPath(path_1.default.resolve(__dirname, '../matrix-config/cssTransformer.js')),
        };
        const configContent = handlebars_1.default.compile(template)(context);
        fs_1.default.writeFileSync(cfgPath, configContent);
    };
    generateBasicConfig();
    return cfgPath;
}
exports.default = generateBasicConfig;
