export declare type RNExtType = 'app_panel' | 'app_popup' | 'zs_anchor_panel' | 'zs_anchor_popup' | 'mid_zs_panel' | 'mid_app_panel';
export declare type Platform = 'ios' | 'android';
export declare type BundleType = 'RN_BUNDLE' | 'MINI_GAME_RN' | string;
export interface RNBuildResult {
    [extType: string]: {
        type: BundleType | string;
        content: {
            engine?: 'h5game' | 'laya';
            sdkVersion: string;
            baseURI: string;
            rnBundle: {
                [platform: string]: {
                    path: string;
                    entries: Array<{
                        name: string;
                        url: string;
                    }>;
                };
            };
            gameSource?: Array<{
                name: string;
                path: string;
                size: number;
                md5: string;
            }>;
        };
    };
}
declare type GenerateUrlOption = {
    extType: string;
    extUuid: string;
    registerComponent: string;
    SDKVersion: string;
    md5: string;
    rnbaseurl?: string;
    rnbasemd5?: string;
};
export declare function generateProdUrl({ extType, extUuid, registerComponent, SDKVersion, md5, rnbaseurl, rnbasemd5, }: GenerateUrlOption): string;
interface BuildInfo {
    extType: RNExtType | string;
    bundleRelativePath: string;
    registerComponents: {
        name: string;
        queryString?: string;
    }[];
    platform: Platform;
    SDKVersion: string;
    bundleType?: BundleType;
}
interface ProdBuildInfo extends BuildInfo {
    bundleMd5: string;
    baseUrl?: string;
    baseMd5?: string;
}
interface UniformBuildInfo extends BuildInfo {
    registerComponents: {
        name: string;
        queryString: string;
    }[];
}
export interface BaseOptions {
    builderName: string;
}
interface ProdOptions extends BaseOptions {
    extInfo: {
        packageName: string;
        extUuid: string;
    };
    buildResultConfig: ProdBuildInfo[];
}
interface DevOptions extends BaseOptions {
    devServerOrigin: string;
    buildResultConfig: BuildInfo[];
}
interface UniformOptions extends BaseOptions {
    devServerOrigin: string;
    buildResultConfig: UniformBuildInfo[];
}
export declare function generateProdBuildResult({ builderName, extInfo, buildResultConfig }: ProdOptions): RNBuildResult;
export declare function generateDevBuildResult({ builderName, devServerOrigin, buildResultConfig }: DevOptions): RNBuildResult;
export declare function generateBuildResult({ builderName, devServerOrigin, buildResultConfig }: UniformOptions): RNBuildResult;
export {};
