"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateBuildResult = exports.generateDevBuildResult = exports.generateProdBuildResult = exports.generateProdUrl = void 0;
const ramda_1 = __importDefault(require("ramda"));
function generateProdUrl({ extType, extUuid, registerComponent, SDKVersion, md5, rnbaseurl, rnbasemd5, }) {
    let values = {
        rnext: 1,
        hyaction: 'newrn',
        // 1. 不要轻易改变这个 rnmodule 格式, 可能会影响到后端的统计
        // 2. 这个名称不要包含非 ascii 值
        rnmodule: `${extUuid}-${extType}-${extUuid}`,
        rnentry: registerComponent,
        sdkversion: SDKVersion,
        rnmd5: md5,
    };
    if (rnbaseurl && rnbasemd5) {
        values = Object.assign(Object.assign({}, values), { rnbaseurl,
            rnbasemd5 });
    }
    return Object.entries(values).map(([k, v]) => `${k}=${encodeURIComponent(v)}`).join('&');
}
exports.generateProdUrl = generateProdUrl;
const generateDevUrl = (component, platform) => {
    return `rnentry=${component}&platform=${platform}&rnext=1&hyaction=newrn`;
};
function generateProdBuildResult({ builderName, extInfo, buildResultConfig }) {
    const config = buildResultConfig.map((cfg) => (Object.assign(Object.assign({}, cfg), { registerComponents: cfg.registerComponents.map(({ name, queryString }) => ({
            name,
            queryString: queryString || generateProdUrl(Object.assign(Object.assign({}, extInfo), { extType: cfg.extType, registerComponent: name, SDKVersion: cfg.SDKVersion, md5: cfg.bundleMd5, rnbaseurl: cfg.baseUrl, rnbasemd5: cfg.baseMd5 })),
        })) })));
    return generateBuildResult({
        builderName,
        devServerOrigin: '',
        buildResultConfig: config,
    });
}
exports.generateProdBuildResult = generateProdBuildResult;
function generateDevBuildResult({ builderName, devServerOrigin, buildResultConfig }) {
    const config = buildResultConfig.map((cfg) => (Object.assign(Object.assign({}, cfg), { registerComponents: cfg.registerComponents.map(({ name, queryString }) => ({
            name,
            queryString: queryString || generateDevUrl(name, cfg.platform)
        })) })));
    return generateBuildResult({
        builderName,
        devServerOrigin,
        buildResultConfig: config,
    });
}
exports.generateDevBuildResult = generateDevBuildResult;
function generateBuildResult({ builderName, devServerOrigin, buildResultConfig }) {
    let buildResult = {};
    buildResultConfig.forEach(({ extType, bundleRelativePath, registerComponents, platform, SDKVersion, bundleType = 'RN_BUNDLE' }) => {
        const result = {
            [extType]: {
                type: bundleType,
                builder: builderName,
                content: {
                    sdkVersion: SDKVersion,
                    baseURI: devServerOrigin,
                    rnBundle: {
                        [platform]: {
                            path: bundleRelativePath,
                            entries: registerComponents.map(({ name, queryString }) => ({
                                name,
                                url: queryString,
                            }))
                        },
                    },
                },
            },
        };
        buildResult = ramda_1.default.mergeDeepLeft(result, buildResult);
    });
    return buildResult;
}
exports.generateBuildResult = generateBuildResult;
