"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateAnimatedValue = exports.validateHyUI = exports.validateVersionList = exports.getVersionFromStr = exports.postAnimatedWarns = void 0;
const child_process_1 = require("child_process");
const semver_1 = __importDefault(require("semver"));
const axios_1 = __importDefault(require("axios"));
const os_1 = require("os");
const minValidVersion = '1.3.29';
const excludeList = [
    '**/node_modules/react-native/*',
    '**/node_modules/react-native-web/*',
    '**/node_modules/@hyext/hy-ui/*',
];
function postAnimatedWarns(files, extUuid) {
    const content = `${extUuid} 使用了 new Animated.Value, 文件列表: \n-${files.join('\n-')}`;
    if (!process.env.RN_ANIMATED_URL)
        return;
    try {
        axios_1.default({
            method: 'post',
            url: process.env.RN_ANIMATED_URL,
            data: {
                msgtype: 'text',
                text: {
                    content,
                },
            },
        });
    }
    catch (err) {
        console.warn('告警发送失败');
    }
}
exports.postAnimatedWarns = postAnimatedWarns;
exports.getVersionFromStr = (content, pkgName = '@hyext/hy-ui') => {
    var _a, _b;
    const reg = new RegExp(`${pkgName}@(.+)$`, 'i');
    const lines = (_b = (_a = content === null || content === void 0 ? void 0 : content.split(os_1.EOL)) === null || _a === void 0 ? void 0 : _a.map(xs => { var _a; return (_a = reg.exec(xs)) === null || _a === void 0 ? void 0 : _a[1]; })) === null || _b === void 0 ? void 0 : _b.filter(xs => !!xs);
    return lines;
};
exports.validateVersionList = (list, baseVersion = minValidVersion) => {
    return list.every(xs => semver_1.default.satisfies(xs, `>=${baseVersion}`, { includePrerelease: true }));
};
function validateHyUI(projectRoot, baseVersion = minValidVersion) {
    const pkgName = '@hyext/hy-ui';
    //   ~/Downloads took 4s
    // ❯ npm --prefix ~/Developer/huya/hyext/just-dance ls @hyext/hy-ui --parseable --long
    // /Users/simon/Developer/huya/hyext/just-dance/node_modules/@hyext/hy-ui:@hyext/hy-ui@1.3.26
    const { stdout, stderr, status, error } = child_process_1.spawnSync('npm', [
        'ls',
        pkgName,
        '--parseable',
        '--long',
    ], {
        cwd: projectRoot,
    });
    if (error)
        return true;
    return exports.validateVersionList(exports.getVersionFromStr(stdout === null || stdout === void 0 ? void 0 : stdout.toString()), baseVersion);
}
exports.validateHyUI = validateHyUI;
function validateAnimatedValue(projectRoot, extUuid, exclude = excludeList) {
    var _a, _b;
    // rg -uuuu -l 'new Animated.Value' ~/Developer/huya/hyext/just-dance --type js -g '!{**/node_modules/react-native/*,**/node_modules/react-native-web/*,**/node_modules/@hyext/hy-ui/*}'
    const { stdout, status, error } = child_process_1.spawnSync('rg', [
        '-uuuuu',
        '--files-with-matches',
        'new Animated.Value',
        projectRoot,
        '--type',
        'js',
        '-g',
        `!{${exclude.join(',')}}`,
    ], {
        cwd: projectRoot,
    });
    if (error) {
        console.warn('validateAnimatedValue error', error.message);
    }
    const files = (_b = (_a = stdout === null || stdout === void 0 ? void 0 : stdout.toString()) === null || _a === void 0 ? void 0 : _a.split(os_1.EOL)) === null || _b === void 0 ? void 0 : _b.filter(xs => !!xs);
    if (files.length > 0) {
        postAnimatedWarns(files.map(xs => xs.replace(`${projectRoot}/`, '')), extUuid);
    }
}
exports.validateAnimatedValue = validateAnimatedValue;
