"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createModuleIdHOF = exports.defaultFactory = void 0;
const path_1 = __importDefault(require("path"));
const pathSep = path_1.default.sep;
function defaultFactory() {
    const fileToIdMap = new Map();
    let nextId = 0;
    return (modulePath) => {
        let id = fileToIdMap.get(modulePath);
        if (typeof id !== 'number') {
            id = nextId++;
            fileToIdMap.set(modulePath, id);
        }
        return id;
    };
}
exports.defaultFactory = defaultFactory;
function createModuleIdHOF({ projectRoot, SDKAlias = {} }) {
    const genSDKReg = (SDKNames) => {
        const uniformNames = SDKNames.map(x => x.replace('/', '_'));
        return new RegExp(`node_modules_(${uniformNames.join('|')})`, 'ig');
    };
    // 如果模块不在 projectRoot 内, 比如 metro-runtime/src/polyfills/requires.js
    // id 变成了 _Users_simon_Developer_huya_hyext_node-pack_node_modules_metro-runtime_src_polyfills_require
    // 为了能正确过滤basebundle中已有的模块(node_modules_metro-runtime_src_polyfills_require), 需要进行处理
    const sepPos = __dirname.indexOf('/node_modules/');
    const parentProjectRoot = `${__dirname.slice(0, sepPos)}`;
    return function createModuleIdFactory() {
        return (modulePath) => {
            //RN JS 全部以 RN_ 开头
            if (modulePath.includes('node_modules' + pathSep + 'react-native' + pathSep + 'Libraries' + pathSep)) {
                return `RN_${path_1.default.basename(modulePath, '.js')}`;
            }
            let name = modulePath
                .replace(`${projectRoot}/`, '')
                .replace(`${parentProjectRoot}/`, '');
            // remove .js extendtion
            name = name.replace(/.js$/, '');
            // 路径分隔符换成 _
            const regExp = pathSep == '\\' ? new RegExp('\\\\', 'g') : new RegExp(pathSep, 'g');
            name = name.replace(regExp, '_');
            // 把业务/base jsbundle 里的非 node_modules 里的模块 id 都带上根目录名
            if (modulePath.includes(projectRoot) && !modulePath.includes('node_modules')) {
                name = path_1.default.basename(projectRoot) + '_' + name;
            }
            Object.entries(SDKAlias).forEach(([alias, SDKNames]) => {
                if (SDKNames.length <= 0)
                    return;
                const SDKReg = genSDKReg(SDKNames);
                if (SDKReg.test(name)) {
                    name = name.replace(SDKReg, alias);
                }
            });
            return name;
        };
    };
}
exports.createModuleIdHOF = createModuleIdHOF;
