/*
 * 0.58 的 rn 版本, 本身代码是和 metro 绑定在一起的
 * 所以最保险的方式是直接调用官方的 cli 去完成打包
 * 这里仅仅是兼容而已, 本地开发应该会全面迁移到 0.62
 */

import path from 'path'
import fs from 'fs-extra'
import { spawnSync } from 'child_process'

import logger from '../lib/logger'

type CliOptions = {
  projectRoot: string
  metroConfigAbsPath: string
}

export default function metroServer({ projectRoot, metroConfigAbsPath }: CliOptions) {
  logger.info('\n正在启动调试服务...\n')

  /*
   * react-native 必须在顶层的 ndoe_modules 下,否则 cli 不能正常工作
   * 项目跟目录之外的文件报hash未计算
   * 所以只需要查找顶层的路径即可
   */
  const cliPath = path.resolve(projectRoot, 'node_modules/react-native/local-cli/cli.js')
  if (!fs.existsSync(cliPath)) {
    logger.error(`\ncli 文件不存在, 请在项目根目录下安装正确的RN版本:`)
    logger.error(`\nnpm i react-native@0.58.5[0.62.2]`)
    process.exit(1)
  }

  /*
   * 同步的进程, 可以接受键盘输入
   */
  return spawnSync(
    'node',
    [
      cliPath,
      'start',
      '--projectRoot',
      projectRoot,
      '--config',
      metroConfigAbsPath,
    ],
    {
      cwd: projectRoot,
      stdio: 'inherit',
      shell: process.platform === 'win32',
    },
  )
}
