import { execSync, spawnSync } from 'child_process'
import semver from 'semver'
import axios from 'axios'
import { EOL } from 'os'

const minValidVersion: string = '1.3.29'
const excludeList: string[] = [
  '**/node_modules/react-native/*',
  '**/node_modules/react-native-web/*',
  '**/node_modules/@hyext/hy-ui/*',
]

export function postAnimatedWarns(files: string[], extUuid: string) {
  const content = `${extUuid} 使用了 new Animated.Value, 文件列表: \n-${files.join('\n-')}`
  if (!process.env.RN_ANIMATED_URL) return

  try {
    axios({
      method: 'post',
      url: process.env.RN_ANIMATED_URL,
      data: {
        msgtype: 'text',
        text: {
          content,
        },
      },
    })
  } catch (err) {
    console.warn('告警发送失败')
  }
}

export const getVersionFromStr = (content: string, pkgName = '@hyext/hy-ui'): string[] => {
  const reg = new RegExp(`${pkgName}@(.+)$`, 'i')

  const lines = content?.split(EOL)?.map(xs => reg.exec(xs)?.[1])?.filter(xs => !!xs)

  return lines as string[]
}

export const validateVersionList = (list: string[], baseVersion = minValidVersion) => {
  return list.every(xs => semver.satisfies(xs, `>=${baseVersion}`, { includePrerelease: true }))
}

export function validateHyUI(projectRoot: string, baseVersion = minValidVersion) {
  const pkgName = '@hyext/hy-ui'
  //   ~/Downloads took 4s
  // ❯ npm --prefix ~/Developer/huya/hyext/just-dance ls @hyext/hy-ui --parseable --long
  // /Users/simon/Developer/huya/hyext/just-dance/node_modules/@hyext/hy-ui:@hyext/hy-ui@1.3.26
  const { stdout, stderr, status, error } = spawnSync('npm',
    [
      'ls',
      pkgName,
      '--parseable',
      '--long',
    ],
    {
      cwd: projectRoot,
    })

  if (error) return true

  return validateVersionList(getVersionFromStr(stdout?.toString()), baseVersion)
}

export function validateAnimatedValue(projectRoot: string, extUuid: string, exclude = excludeList) {
  // rg -uuuu -l 'new Animated.Value' ~/Developer/huya/hyext/just-dance --type js -g '!{**/node_modules/react-native/*,**/node_modules/react-native-web/*,**/node_modules/@hyext/hy-ui/*}'
  const { stdout, status, error } = spawnSync('rg',
    [
      '-uuuuu',
      '--files-with-matches',
      'new Animated.Value',
      projectRoot,
      '--type',
      'js',
      '-g',
      `!{${exclude.join(',')}}`,
    ],
    {
      cwd: projectRoot,
    }
  )

  if (error) {
    console.warn('validateAnimatedValue error', error.message)
  }

  const files = stdout?.toString()?.split(EOL)?.filter(xs => !!xs)

  if (files.length > 0) {
    postAnimatedWarns(files.map(xs => xs.replace(`${projectRoot}/`, '')), extUuid)
  }
}
